@@ -35,8 +35,24 @@ def ImportCoco(path, path_to_images=None, name=""):
     #Store the 3 sections of the json as seperate json arrays
     images = pd.json_normalize(annotations_json["images"])
     images.columns = 'img_' + images.columns
-    images["img_folder"] = _GetValueOrBlank(images["img_folder"], path_to_images)
-    images = images.astype({'img_width': 'int64','img_height': 'int64','img_depth': 'int64'})
+    try:
+        images["img_folder"]
+    except:
+        images["img_folder"] = ""
+    #print(images)
+
+    #If the user has specified a different image folder then use that one
+    if path_to_images != None:
+        images["img_folder"] = path_to_images
+
+    astype_dict = {'img_width': 'int64','img_height': 'int64','img_depth': 'int64'}
+    astype_keys = list(astype_dict.keys())
+    for element in astype_keys:
+        if element not in images.columns:
+            astype_dict.pop(element)
+    #print(astype_dict)
+    #images = images.astype({'img_width': 'int64','img_height': 'int64','img_depth': 'int64'})
+    images = images.astype(astype_dict)
 
     annotations = pd.json_normalize(annotations_json["annotations"])
     annotations.columns = 'ann_' + annotations.columns
@@ -386,4 +402,4 @@ def ImportYoloV5WithYaml(yaml_file, split_type=None, image_ext="jpg", name="coco
                 dataset2.df['split'] = splitted
                 dataset.df = dataset.df.append(dataset2.df)
                 counter += 1
-    return(dataset)
\ No newline at end of file
+    return(dataset)
